@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -127,6 +127,7 @@ extern struct t_config_file *weechat_config_file;
 extern struct t_config_section *weechat_config_section_color;
 extern struct t_config_section *weechat_config_section_proxy;
 extern struct t_config_section *weechat_config_section_bar;
+extern struct t_config_section *weechat_config_section_custom_bar_item;
 extern struct t_config_section *weechat_config_section_notify;
 
 extern struct t_config_option *config_startup_command_after_plugins;
@@ -342,7 +343,6 @@ extern struct t_config_option *config_network_gnutls_handshake_timeout;
 extern struct t_config_option *config_network_proxy_curl;
 
 extern struct t_config_option *config_plugin_autoload;
-extern struct t_config_option *config_plugin_debug;
 extern struct t_config_option *config_plugin_extension;
 extern struct t_config_option *config_plugin_path;
 extern struct t_config_option *config_plugin_save_config_on_unload;
