@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_XFER_BUFFER_H
-#define WEECHAT_XFER_BUFFER_H 1
+#ifndef WEECHAT_PLUGIN_XFER_BUFFER_H
+#define WEECHAT_PLUGIN_XFER_BUFFER_H
 
 #define XFER_BUFFER_NAME "xfer.list"
 
@@ -26,9 +26,11 @@ extern struct t_gui_buffer *xfer_buffer;
 extern int xfer_buffer_selected_line;
 
 extern void xfer_buffer_refresh (const char *hotlist);
-extern int xfer_buffer_input_cb (void *data, struct t_gui_buffer *buffer,
+extern int xfer_buffer_input_cb (const void *pointer, void *data,
+                                 struct t_gui_buffer *buffer,
                                  const char *input_data);
-extern int xfer_buffer_close_cb (void *data, struct t_gui_buffer *buffer);
+extern int xfer_buffer_close_cb (const void *pointer, void *data,
+                                 struct t_gui_buffer *buffer);
 extern void xfer_buffer_open ();
 
-#endif /* WEECHAT_XFER_BUFFER_H */
+#endif /* WEECHAT_PLUGIN_XFER_BUFFER_H */
